# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/), and this project
adheres to [Semantic Versioning](https://semver.org/).

## 1.0.0 - 2022-01-09 Upcoming

[1.0.0]: https://github.com/elomagic/spps-py/releases/tag/v1.0.0

* 💡 FEATURE Initial release
* 